.. py:currentmodule:: rubin_sim

.. _phot-utils:

##########
Phot Utils
##########

The ``rubin_sim.photUtils`` module provides synthetic photometry
and SNR calculation methods for Rubin. There are expected throughput
curves available in the 'throughputs' directory of $RUBIN_SIM_DATA_DIR.